# -*- coding: utf-8 -*-

"""Top-level package for Hotelling T2."""

__author__ = """Francois Dion"""
__email__ = "fdion@dionresearch.com"
__version__ = "0.4.3"
